@@ -35,25 +35,25 @@ import shutil
 import pickle
 import cairo
 
-print "DeVeDe 3.10"
+print "DeVeDe 3.12"
 if sys.platform!="win32":
 	print "Locale: "+str(os.environ["LANG"])
 
 # append the directories where we install the devede's own modules
 tipo=-1
 try:
-	fichero=open("/usr/local/share/devede/devede.glade","r")
+	fichero=open("/usr/share/devede/devede.glade","r")
 	fichero.close()
-	tipo=1
+	tipo=0
 	found=True
 except:
 	found=False
 
 if found==False:
 	try:
-		fichero=open("/usr/share/devede/devede.glade","r")
+		fichero=open("/usr/local/share/devede/devede.glade","r")
 		fichero.close()
-		tipo=0
+		tipo=1
 		found=True
 	except:
 		found=False
@@ -173,6 +173,12 @@ except:
 	print "Failed to load module DEVEDE_DISCTYPE"
 	sys.exit(1)
 
+try:
+	import devede_fonts
+except:
+	print "Failed to load module DEVEDE_FONTS"
+	sys.exit(1)
+
 
 home=devede_other.get_home_directory()
 
@@ -210,48 +216,14 @@ if font_path[-1]!=os.sep:
 font_path+="devedesans.ttf"
 global_vars["font_path"]=font_path
 
-#if our font for subtitles isn't installed, we install it
-
-try:
-	if sys.platform!='win32':
-		fichero=open(home+".spumux/devedesans.ttf")
-		fichero.close()
-	else: # get home
-		t=os.path.join(os.environ["WINDIR"], "Fonts", "devedesans.ttf")
-		fichero=open(t)
-		fichero.close()
-except:
-	if sys.platform=='win32':
-		t=os.path.join(os.environ["WINDIR"], "Fonts" )#=r'C:\WINDOWS\Fonts\\'
-		# spummux needs font in the windows font directory
-		print "\n\nFont Path: " , font_path
-		print "\n\nT: " , t
-		shutil.copyfile(font_path,t+os.sep+"devedesans.ttf")
-	else:
-		handle=subprocess.Popen("mkdir "+home+".spumux",bufsize=8192,shell=True)
-		handle.wait()
-		handle=subprocess.Popen("cp "+font_path+" "+home+".spumux/",bufsize=8192,shell=True)
-		handle.wait()
+print "Entro en fonts"
+fonts_found=devede_fonts.prepare_devede_font(home,font_path)
+print "Salgo de fonts"
 
 devede_other.load_config(global_vars) # load configuration
 
 errors="" # check for installed programs
-if not sys.platform=='win32': 
-	if 127==devede_other.check_program("mplayer -v"):
-		errors+="mplayer\n"
-	if 127==devede_other.check_program("mencoder -msglevel help"):
-		errors+="mencoder\n"
-	if 127==devede_other.check_program("dvdauthor --help"):
-		errors+="dvdauthor\n"
-	if 127==devede_other.check_program("vcdimager --help"):
-		errors+="vcdimager\n"
-	if 127==devede_other.check_program("mkisofs -help"):
-		errors+="mkisofs\n"
-	if 127==devede_other.check_program("spumux --help"):
-		errors+="spumux\n"
-	if 127==devede_other.check_program("convert --help"):
-		errors+="convert (imagemagick)\n"
-else:
+if sys.platform=='win32':
 	try:
 		devede_other.check_program(["mplayer.exe", "-v"])
 	except:
@@ -268,18 +240,47 @@ else:
 		devede_other.check_program(["vcdimager.exe", "--help"])
 	except:
 		errors+="vcdimager\n"
+	
 	try:
 		devede_other.check_program(["mkisofs.exe"])
+		mkisofs=True
+		global_vars["iso_creator"]="mkisofs.exe"
 	except:
-		errors+="mkisofs\n"
+		mkisofs=False
+
+	if mkisofs==False:
+		try:
+			devede_other.check_program(["genisoimage.exe"])
+			global_vars["iso_creator"]="genisoimage.exe"
+		except:
+			errors+="genisoimage/mkisofs\n"
+
 	try:
 		devede_other.check_program(["spumux.exe", "--help"])
 	except:
 		errors+="spumux\n"
-	try:
-		devede_other.check_program(["convert.exe", "--help"])
-	except:
-		errors+="convert (imagemagick)\n"
+
+else:
+
+	if 127==devede_other.check_program("mplayer -v"):
+		errors+="mplayer\n"
+	if 127==devede_other.check_program("mencoder -msglevel help"):
+		errors+="mencoder\n"
+	if 127==devede_other.check_program("dvdauthor --help"):
+		errors+="dvdauthor\n"
+	if 127==devede_other.check_program("vcdimager --help"):
+		errors+="vcdimager\n"
+	if 127==devede_other.check_program("mkisofs -help"):
+		if 127==devede_other.check_program("genisoimage -help"):
+			errors+="genisoimage/mkisofs\n"
+		else:
+			global_vars["iso_creator"]="genisoimage"
+	else:
+		global_vars["iso_creator"]="mkisofs"
+
+	if 127==devede_other.check_program("spumux --help"):
+		errors+="spumux\n"
+
 
 def program_exit(widget):
 	
@@ -293,6 +294,12 @@ if errors!="":
 	w=arbol.get_widget("program_exit")
 	w.connect("clicked",program_exit)
 	wprograms.connect("destroy",program_exit)
+elif fonts_found==False:
+	wprograms=arbol.get_widget("wnofonts")
+	wprograms.show()
+	w=arbol.get_widget("fonts_program_exit")
+	w.connect("clicked",program_exit)
+	wprograms.connect("destroy",program_exit)
 else:
 	new_file=devede_disctype.disctype(global_vars)
 
