@@ -70,7 +70,7 @@ class iso_generator(devede_executor.executor):
 	
 	""" This class generates the ISO image for DVDs """
 	
-	def __init__(self,filename,filefolder,progresbar,proglabel):
+	def __init__(self,filename,filefolder,progresbar,proglabel,command):
 		
 		devede_executor.executor.__init__(self,filename,filefolder,progresbar)
 		
@@ -78,13 +78,6 @@ class iso_generator(devede_executor.executor):
 		progresbar.set_fraction(0.0)
 		progresbar.set_text("0%")
 	
-		command=""
-
-		if sys.platform=='win32':
-			command="mkisofs.exe"
-		else:
-			command="mkisofs"
-
 		volume="DVDVIDEO"
 		self.print_error=_("Failed to create the ISO image\nMaybe you ran out of disk space")
 		self.launch_program([command,"-dvd-video","-V",volume,"-v","-o",filefolder+filename+".iso",filefolder+filename])
