@@ -149,7 +149,7 @@ class main_window:
 		if delete_structure:
 			self.structure=[]
 			self.structure.append(self.create_new_structure(1))
-		self.set_default_global()
+			self.set_default_global()
 		
 		self.disctocreate = self.global_vars["disctocreate"]
 		
@@ -474,14 +474,20 @@ class main_window:
 	
 	
 	def on_main_go_clicked(self,widget):
+
+		total=0
+		for title in self.structure:
+			total+=len(title)-1
 	
 		if self.disctocreate=="dvd":
-			total=0
-			for title in self.structure:
-				total+=len(title)-1
 			
-			if total>90:
-				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is 90. Please, remove some files and try again.")) % {"X":total})
+			if total>61:
+				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is %(MAX)d. Please, remove some files and try again.")) % {"X":total , "MAX":61})
+				return
+
+		else:
+			if total>99:
+				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is %(MAX)d. Please, remove some files and try again.")) % {"X":total , "MAX":99})
 				return
 	
 		actions=0	
@@ -721,6 +727,7 @@ class main_window:
 		if load.done==False:
 			load=None
 			return
+		
 		self.set_disc_type(False)
 		self.refresh_titles()
 		self.refresh_chapters()
@@ -852,7 +859,7 @@ class main_window:
 			del_title.set_sensitive(False)
 		
 		add_title=self.tree.get_widget("add_title")
-		if (len(self.structure)<90):
+		if (len(self.structure)<61):
 			add_title.set_sensitive(True)
 		else:
 			add_title.set_sensitive(False)
